@@ -166,9 +166,16 @@ setGeneric(
 #'  interpret `x` in a suitable way (see [grDevices::xy.coords()]).
 #' @param n An [`integer`] value giving the number of iterations.
 #' @param m An odd [`integer`] giving the half window size.
-#' @inheritParams smooth_whittaker
-#' @inheritParams resample_bin
-#' @seealso [signal_correct()]
+#' @param by A length-one [`numeric`] vector givging the umber of buckets to
+#'  divide `x` into.
+#' @param lambda An [`integer`] giving the smoothing parameter. The larger
+#'  `lambda` is, the smoother the curve (see [smooth_whittaker()]).
+#' @param d An [`integer`] specifying the order of the penalty (see
+#'  [smooth_whittaker()]).
+#' @param sparse A [`logical`] scalar: should sparse matrices be used for
+#'  computation (see [smooth_whittaker()])? If `TRUE`, \pkg{Matrix} is required.
+#' @param ... Currently not used.
+#' @seealso [signal_correct()], [smooth_whittaker()]
 #' @references
 #'  Liland, K. H. (2015). 4S Peak Filling - baseline estimation by iterative
 #'  mean suppression. *MethodsX*, 2, 135-140. \doi{10.1016/j.mex.2015.02.009}.
@@ -810,6 +817,73 @@ setGeneric(
   valueClass = "list"
 )
 
+#' Penalized Likelihood Smoothing
+#'
+#' @param x,y A [`numeric`] vector. If `y` is missing, an attempt is made to
+#'  interpret `x` in a suitable way (see [grDevices::xy.coords()]).
+#' @param lambda An [`integer`] giving the smoothing parameter. The larger
+#'  `lambda` is, the smoother the curve.
+#' @param d An [`integer`] specifying the order of the penalty.
+#' @param SE A [`logical`] scalar: should standard errors be returned?
+#' @param progress A [`logical`] scalar: should a progress bar be displayed?
+#' @param ... Currently not used.
+#' @return
+#'  Returns a [`list`] with two components `x` and `y`.
+#' @note
+#'  \pkg{Matrix} is required.
+#' @references
+#'  de Rooi, J. J., van der Pers, N. M., Hendrikx, R. W. A., Delhez, R.,
+#'  Böttger A. J. and Eilers, P. H. C. (2014). Smoothing of X-ray diffraction
+#'  data and Ka2 elimination using penalized likelihood and the composite link
+#'  model. *Journal of Applied Crystallography*, 47: 852-860.
+#'  \doi{10.1107/S1600576714005809}
+#' @author J. J. de Rooi *et al.* (original R code).
+#' @example inst/examples/ex-xrd-ka2.R
+#' @docType methods
+#' @family smoothing methods
+#' @aliases smooth_likelihood-method
+setGeneric(
+  name = "smooth_likelihood",
+  def = function(x, y, ...) standardGeneric("smooth_likelihood"),
+  valueClass = "list"
+)
+
+# Strip ========================================================================
+#' Strip XRD ka2
+#'
+#' @param x,y A [`numeric`] vector. If `y` is missing, an attempt is made to
+#'  interpret `x` in a suitable way (see [grDevices::xy.coords()]).
+#' @param lambda An [`integer`] giving the smoothing parameter. The larger
+#'  `lambda` is, the smoother the curve.
+#' @param wave A length-two [`numeric`] vector giving the characteristic
+#'  wavelengths of the anode material (defaults to copper).
+#' @param tau A length-one [`numeric`] vector giving the ratio between
+#'  \eqn{\alpha}1 and \eqn{\alpha}2 line intensities (defaults to 1/2).
+#' @param nseg A length-one [`numeric`] vector specifying the number of equally
+#'  sized segments for B-spline basis matrix computation.
+#' @param progress A [`logical`] scalar: should a progress bar be displayed?
+#' @param ... Currently not used.
+#' @return
+#'  Returns a [`list`] with two components `x` and `y`.
+#' @note
+#'  \pkg{Matrix} is required.
+#' @author J. J. de Rooi *et al.* (original R code).
+#' @references
+#'  de Rooi, J. J., van der Pers, N. M., Hendrikx, R. W. A., Delhez, R.,
+#'  Böttger A. J. and Eilers, P. H. C. (2014). Smoothing of X-ray diffraction
+#'  data and Ka2 elimination using penalized likelihood and the composite link
+#'  model. *Journal of Applied Crystallography*, 47: 852-860.
+#'  \doi{10.1107/S1600576714005809}
+#' @example inst/examples/ex-xrd-ka2.R
+#' @docType methods
+#' @family specialized tools
+#' @aliases ka2_strip_penalized-method
+setGeneric(
+  name = "ka2_strip_penalized",
+  def = function(x, y, ...) standardGeneric("ka2_strip_penalized"),
+  valueClass = "list"
+)
+
 # Windows ======================================================================
 #' Sliding Windows
 #'
